@@ -25,10 +25,17 @@
 
 LISTFILES=$(cat list-of-packages-extra | egrep -v "^#" | egrep '(FED|FGD)' | cut -d" " -f1 | tr '|' ' ')
 
+# Pre-checking
+
+apt-get install --no-install-recommends -s $LISTFILES | grep '^Inst' | grep $1 > /dev/null || \
+    { echo -e "\nNot found packages depending of $1.\nNote this script only checks packages set as FED and FGD.\n"; exit 0; }
+
+# Package by package check
+
 for i in $(echo $LISTFILES)
 do
     echo $i; apt-get install --no-install-recommends -s $i | grep '^Inst' | grep $1 && \
-    { echo -e "\nBreaking...\n\nI found a package depending of $1: $i.\nPlease, fix list-of-files-extra and run find-deps.sh again."; break; }
+    { echo -e "\nBreaking...\n\nI found a package depending of $1: $i.\nPlease, fix list-of-files-extra and run find-deps.sh again.\n"; break; }
 done
 
 exit 0
